==> tuia-news-center-api-0.0.28-zwb15-20180515.133838-2-sources.jar: cn/com/duiba/tuia/news/center/dto/req/MediaAccountDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.util.Date;
import java.util.List;

public class MediaAccountDto {

    private Long id;
    /**
     * 自媒体账号名称
     */
    private String nickName;

    /**
     * 账号
     */
    private String account;

    /**
     * 冻结状态
     */
    private Integer freezenStatus;

    /**
     * 头像
     *
     */
    private String imageUrl;

    /**
     * 微信
     */
    private String wechat;

    /**
     * 介绍
     *
     */
    private String intro;

    /**
     *微博主页
     */
    private String blog;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 电话
     */
    private String tel;

    /**
     * 标签(弃用)
     */
    private String tags;

    /**
     * 密码
     */
    private String passwd;

    /**
     * 操作人id
     */
    private Long optId;

    /**
     * 计费模式
     */
    private Integer chargeType;

    /**
     *千次曝光单价
     */
    private Integer mexposurePrice;

    /**
     * 文章数
     */
    private Long articleSum;

    /**
     * 标签内容
     */
    private List<String> tagsContent;

    /**
     * 授权开始时间
     */
    private Date gmtStart;

    /**
     *自动冻结时间
     */
    private Date gmtAutoFreezen;

    /**
     * 代理账号Id
     */
    private Long parentId;

    /**
     * 代理账号状态
     */
    private Integer parentFreezenStatus;

    /**
     * 分润比例
     */
    private Long proportion;

    /**
     * 代理账号名称
     */
    private String parentName;

    /**
     *新标签id路径
     * @return
     */
    private String tagIds;

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getIntro() {
        return intro;
    }

    public void setIntro(String intro) {
        this.intro = intro;
    }

    public String getBlog() {
        return blog;
    }

    public void setBlog(String blog) {
        this.blog = blog;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getPasswd() {
        return passwd;
    }

    public void setPasswd(String passwd) {
        this.passwd = passwd;
    }

    public Long getOptId() {
        return optId;
    }

    public void setOptId(Long optId) {
        this.optId = optId;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Integer getMexposurePrice() {
        return mexposurePrice;
    }

    public void setMexposurePrice(Integer mexposurePrice) {
        this.mexposurePrice = mexposurePrice;
    }

    public Date getGmtStart() {
        return gmtStart;
    }

    public void setGmtStart(Date gmtStart) {
        this.gmtStart = gmtStart;
    }

    public Date getGmtAutoFreezen() {
        return gmtAutoFreezen;
    }

    public void setGmtAutoFreezen(Date gmtAutoFreezen) {
        this.gmtAutoFreezen = gmtAutoFreezen;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Integer getFreezenStatus() {
        return freezenStatus | this.parentFreezenStatus;
    }

    public void setFreezenStatus(Integer freezenStatus) {
        this.freezenStatus = freezenStatus;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getWechat() {
        return wechat;
    }

    public void setWechat(String wechat) {
        this.wechat = wechat;
    }

    public Long getArticleSum() {
        return articleSum;
    }

    public void setArticleSum(Long articleSum) {
        this.articleSum = articleSum;
    }

    public List<String> getTagsContent() {
        return tagsContent;
    }

    public void setTagsContent(List<String> tagsContent) {
        this.tagsContent = tagsContent;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Integer getParentFreezenStatus() {
        return parentFreezenStatus;
    }

    public void setParentFreezenStatus(Integer parentFreezenStatus) {
        this.parentFreezenStatus = parentFreezenStatus;
    }

    public Long getProportion() {
        return proportion;
    }

    public void setProportion(Long proportion) {
        this.proportion = proportion;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }

    public String getTagIds() {
        return tagIds;
    }

    public void setTagIds(String tagIds) {
        this.tagIds = tagIds;
    }
}

==> tuia-news-center-api-1.9.4.0.zwb1-20190307.032249-3-sources.jar: cn/com/duiba/tuia/news/center/dto/req/MediaAccountDto.java <==
package cn.com.duiba.tuia.news.center.dto.req;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class MediaAccountDto implements Serializable {

    private Long id;
    /**
     * 自媒体账号名称
     */
    private String nickName;

    /**
     * 账号
     */
    private String account;

    /**
     * 冻结状态
     */
    private Integer freezenStatus;

    /**
     * 头像
     *
     */
    private String imageUrl;

    /**
     * 微信
     */
    private String wechat;

    /**
     * 介绍
     *
     */
    private String intro;

    /**
     *微博主页
     */
    private String blog;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 电话
     */
    private String tel;

    /**
     * 标签(弃用)
     */
    private String tags;

    /**
     * 密码
     */
    private String passwd;

    /**
     * 操作人id
     */
    private Long optId;

    /**
     * 计费模式
     */
    private Integer chargeType;

    /**
     *千次曝光单价
     */
    private Integer mexposurePrice;

    /**
     * 文章数
     */
    private Long articleSum;

    /**
     * 标签内容
     */
    private List<String> tagsContent;

    /**
     * 授权开始时间
     */
    private Date gmtStart;

    /**
     *自动冻结时间
     */
    private Date gmtAutoFreezen;

    /**
     * 代理账号Id
     */
    private Long parentId;

    /**
     * 代理账号状态
     */
    private Integer parentFreezenStatus;

    /**
     * 分润比例
     */
    private Long proportion;

    /**
     * 代理账号名称
     */
    private String parentName;

    /**
     *新标签id路径
     * @return
     */
    private String tagIds;

    /**
     * 分成比例
     */
    private Integer finalProportion;

    /**
     * 第三方关联id
     */
    private String thirdId;

    public String getThirdId() {
        return thirdId;
    }

    public void setThirdId(String thirdId) {
        this.thirdId = thirdId;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }

    public String getIntro() {
        return intro;
    }

    public void setIntro(String intro) {
        this.intro = intro;
    }

    public String getBlog() {
        return blog;
    }

    public void setBlog(String blog) {
        this.blog = blog;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getPasswd() {
        return passwd;
    }

    public void setPasswd(String passwd) {
        this.passwd = passwd;
    }

    public Long getOptId() {
        return optId;
    }

    public void setOptId(Long optId) {
        this.optId = optId;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Integer getMexposurePrice() {
        return mexposurePrice;
    }

    public void setMexposurePrice(Integer mexposurePrice) {
        this.mexposurePrice = mexposurePrice;
    }

    public Date getGmtStart() {
        return gmtStart;
    }

    public void setGmtStart(Date gmtStart) {
        this.gmtStart = gmtStart;
    }

    public Date getGmtAutoFreezen() {
        return gmtAutoFreezen;
    }

    public void setGmtAutoFreezen(Date gmtAutoFreezen) {
        this.gmtAutoFreezen = gmtAutoFreezen;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Integer getFreezenStatus() {
        return freezenStatus;
    }

    public void setFreezenStatus(Integer freezenStatus) {
        this.freezenStatus = freezenStatus;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getWechat() {
        return wechat;
    }

    public void setWechat(String wechat) {
        this.wechat = wechat;
    }

    public Long getArticleSum() {
        return articleSum;
    }

    public void setArticleSum(Long articleSum) {
        this.articleSum = articleSum;
    }

    public List<String> getTagsContent() {
        return tagsContent;
    }

    public void setTagsContent(List<String> tagsContent) {
        this.tagsContent = tagsContent;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Integer getParentFreezenStatus() {
        return parentFreezenStatus;
    }

    public void setParentFreezenStatus(Integer parentFreezenStatus) {
        this.parentFreezenStatus = parentFreezenStatus;
    }

    public Long getProportion() {
        return proportion;
    }

    public void setProportion(Long proportion) {
        this.proportion = proportion;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }

    public String getTagIds() {
        return tagIds;
    }

    public void setTagIds(String tagIds) {
        this.tagIds = tagIds;
    }

    public Integer getFinalProportion() {
        return finalProportion;
    }

    public void setFinalProportion(Integer finalProportion) {
        this.finalProportion = finalProportion;
    }
}
